# version_acronym is either sl or slf
# lower case please!
%define version_acronym sl

%define base_release_version 7
%define minor_release_version 0

# increment this to get the stuff after the - higher
#  helps for making the rolling one go obsolete
%define release_count 0.0

# set ROLLING true for the rolling tree
#  once set it will do the rest for you automatically
#  the only valid values are true and anything else
%define ROLLING true

%define product_family Scientific Linux

# setup pretty name
%if %(echo %{version_acronym} | grep -c 'slf')
    %define release_name ??????
    %define variant_titlecase Fermi
    %define variant_lowercase fermi
    %define list linux-users@listserv.fnal.gov
    %define betalist linux-users@listserv.fnal.gov
%else
    %define release_name Nitrogen
    %define beta_directory 7rolling
    %define list scientific-linux-users@listserv.fnal.gov
    %define betalist scientific-linux-users@listserv.fnal.gov
%endif

%define withpublican false

#############################################################

%define debug_package %{nil}

%define emaillist %{list}

%define now %{expand:date}

# if we are building for the rolling tree, define beta
%if %(echo %{ROLLING} |grep -c 'true')
    %define beta rolling
    %define emaillist %{betalist}
%endif

#Publican Documentation Specfile
%define RHEL5 %(test %{?dist} == .el5 && echo 1 || echo 0)
%define HTMLVIEW %(test %{RHEL5} == 1 && echo 1 || echo 0)

%define ICONS 0

%define viewer xdg-open

%if %{HTMLVIEW}
%define viewer htmlview
%define vendor %{version_acronym}
%define vendoropt %{nil}
%endif

Name:         %{version_acronym}-release-notes
Version:      %{base_release_version}.%{minor_release_version}
Release:      %{release_count}.sl7%{?beta:.%{beta}}

%if %(echo %{withpublican} |grep -c 'true')
Source0:	Red_Hat_Enterprise_Linux-Release_Notes-%{base_release_version}-en-US-%{minor_release_version}.2.tgz
Source1:        %{name}-%{base_release_version}.tgz
%else
Source:        %{name}-%{base_release_version}.tgz
%endif

Summary:       Release Notes for %{product_family}%{?variant_titlecase: %{variant_titlecase}} %{base_release_version}.%{minor_release_version}
Group:         Documentation
License:       CC-BY-SA
URL:           http://www.scientificlinux.org
BuildArch:      noarch

BuildRequires: desktop-file-utils

BuildRequires:    asciidoc

# for making the RH logos and legal import
%if %(echo %{withpublican} |grep -c 'true')
BuildRequires:    publican-redhat
BuildRequires: publican >= 3.0
%endif



%if %{HTMLVIEW}
Requires:    htmlview
%else
Requires:    xdg-utils
%endif


%description
Scientific Linux%{?variant_titlecase: %{variant_titlecase}} %{version} release notes.
As well as the Upstream Vendors release notes (English).

%prep

%if %(echo %{withpublican} |grep -c 'true')
%setup -q -n Red_Hat_Enterprise_Linux-Release_Notes-%{base_release_version}-en-US-%{minor_release_version}
tar xvf %{SOURCE1} --overwrite --strip-components=1
%else
%setup -q -n %{name}-%{base_release_version}
%endif

%build
%if %(echo %{withpublican} |grep -c 'true')
publican build --nocolours --formats="html-desktop" --langs=en-US
%endif

cd sl-release-notes-%{base_release_version}
asciidoc -a toc -a version=%{version} -a maillist=%{emaillist} -a date=%{now} index.asciidoc

%if %(echo %{version_acronym} | grep -c 'slf')
cd slf-release-notes-%{base_release_version}
asciidoc -a toc -a version=%{version} -a maillist=%{emaillist} -a date=%{now} index.asciidoc
%endif


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps

%if %{ICONS}
for icon in `ls en-US/icons/*x*.png`; do
  size=`echo "$icon" | sed -e 's/.*icons\/\(.*\)\.png/\1/'`;
  mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/$size/apps
  cp $icon  $RPM_BUILD_ROOT/usr/share/icons/hicolor/$size/apps/Release_Notes-%{base_release_version}-en-US.png;
done
cp en-US/icons/icon.svg  $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/Release_Notes-%{base_release_version}-en-US.svg;
%else
cp en-US/images/icon.svg  $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/Release_Notes-%{base_release_version}-en-US.svg;
%endif

%if %(echo %{withpublican} |grep -c 'true')
# Move TUV's release notes over to TUV
mv tmp/en-US/html-desktop/index.html tmp/en-US/html-desktop/tuv.index.html

# URL provided CC-BY-SA now OK
cat > TUV-notes.desktop <<'EOF'
[Desktop Entry]
Name=The Upstream Vendor %{version}: Release Notes
Comment=Release Notes for The Upstream Vendor %{version} Release
Exec=%{viewer} %{_docdir}/%{name}-%{version}/tuv.index.html
Icon=Release_Notes-%{base_release_version}-en-US
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF
%else
cat > TUV-notes.desktop <<'EOF'
[Desktop Entry]
Name=The Upstream Vendor %{version}: Release Notes
Comment=Release Notes for The Upstream Vendor %{version} Release
Icon=Release_Notes-%{base_release_version}-en-US
Type=Link
Encoding=UTF-8
URL=https://access.redhat.com/site/documentation/en-US/Red_Hat_Enterprise_Linux/%{base_release_version}/html/%{version}_Release_Notes/
EOF
%endif

mkdir -p tmp/en-US/html-desktop/
mv sl-release-notes-%{base_release_version}/index.html tmp/en-US/html-desktop/index.html

cat > SL-notes.desktop <<'EOF'
[Desktop Entry]
Name=Scientific Linux %{version}: Release Notes
Comment=Release Notes for Scientific Linux %{version}
Exec=%{viewer} %{_docdir}/%{name}-%{version}/index.html
Icon=Release_Notes-%{base_release_version}-en-US
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF

desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications TUV-notes.desktop
desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SL-notes.desktop

# For SLF
%if %(echo %{version_acronym} | grep -c 'slf')

mv slf-release-notes-%{base_release_version}/index.html tmp/en-US/html-desktop/slf.index.html

cat > SLF-notes.desktop <<'EOF'
[Desktop Entry]
Name=Scientific Linux Fermi %{version}: Release Notes
Comment=Release Notes for Scientific Linux Fermi %{version}
Exec=%{viewer} %{_docdir}/%{name}-%{version}/slf.index.html
Icon=Release_Notes-%{base_release_version}-en-US
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF

desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SLF-notes.desktop

%endif


# Update Icon cache if it exists
%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc tmp/en-US/html-desktop/*
%{_datadir}/applications/*
%if %{ICONS}
/usr/share/icons/hicolor/*
%else
/usr/share/icons/hicolor/scalable/apps/Release_Notes-%{base_release_version}-en-US.svg
%endif

%changelog

* Tue Jun 10 2014 Eliska Slobodova <eslobodo@redhat.com> - 0-2
- Release of the Red Hat Enterprise Linux 7.0 Release Notes.

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 0-1
- Mass rebuild 2013-12-27

* Wed Dec 11 2013 Eliska Slobodova <eslobodo@redhat.com> - 0-0
- Release of the Red Hat Enterprise Linux 7.0 Beta Release Notes 

